// -*- mode: C++; c-file-style: "Stroustrup" -*-
//
// This file is part of krot,
// a program for the simulation, assignment and fit of HRLIF spectra.
//
// Copyright (C) 1998 Jochen Kpper
//
// This program is free software; you can redistribute it and/or modify it under
// the terms of the GNU General Public License as published by the Free Software
// Foundation; either version 2 of the License, or (at your option) any later
// version.
//
// This program is distributed in the hope that it will be useful, but WITHOUT
// ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
// FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for
// more details.
//
// You should have received a copy of the GNU General Public License along with
// this program; see the file License. if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
//
// If you use this program for your scientific work, please cite it according to
// the file CITATION that comes with the package.
//
// $Id: scrollbar64_inline.h,v 1.3 1998/10/09 14:49:20 jochen Exp $


#ifndef KROT_SCROLLBAR_INLINE_H
#define KROT_SCROLLBAR_INLINE_H


#include "krot.h"

#include <climits>



inline ScrollBar64::~ScrollBar64()
{
    delete qscrollbar;
    return;
}



inline bool ScrollBar64::draggingSlider () const
{
    return qscrollbar->draggingSlider();
}



inline void ScrollBar64::doIt()
{
    const int MIN_VAL = INT_MIN + qscrollbar->pageStep() + 1,
	      MAX_VAL = INT_MAX - qscrollbar->pageStep() - 1;
    div = 1;
    while( ( ( max - min ) / div )  >  ( static_cast< int64_t >( MAX_VAL ) - MIN_VAL ) )
	div++;
    shift = static_cast< int64_t >( MIN_VAL ) - ( min / div );
    qscrollbar->setRange( static_cast< int >( ( min + shift ) / div ),
			  static_cast< int >( ( max + shift ) / div ) );
    qscrollbar->setSteps( static_cast< int >( line / div ),
			  static_cast< int >( page / div ) );
    qscrollbar->setValue( static_cast< int >( ( val + shift ) / div ) );
    return;
}



inline void ScrollBar64::init()
{
    connect( qscrollbar, SIGNAL( valueChanged( int ) ),
	     this,       SLOT( slotValueChanged( int ) ) );
    connect( qscrollbar, SIGNAL( sliderMoved( int ) ),
	     this,       SLOT( slotSliderMoved( int ) ) );
    return;
}



inline ScrollBar64::Orientation ScrollBar64::orientation() const
{
    return qscrollbar->orientation();
}



inline void ScrollBar64::resizeEvent( QResizeEvent *event )
{
    qscrollbar->resize( event->size() );
    return;
}



inline void ScrollBar64::setOrientation( Orientation o )
{
    qscrollbar->setOrientation( o );
    return;
}



inline void ScrollBar64::setPalette( const QPalette & pal )
{
    qscrollbar->setPalette( pal );
    return;
}



inline void ScrollBar64::setRange( int64_t minValue, int64_t maxValue )
{
    min = minValue;
    max = maxValue > min ? maxValue : min;
    doIt();
    return;
}



inline void ScrollBar64::setSteps( int64_t lineStep, int64_t pageStep )
{
    line = lineStep;
    page = pageStep > line ? pageStep : line;
    doIt();
    return;
}



inline void ScrollBar64::setTracking( bool enable )
{
    qscrollbar->setTracking( enable );
    return;
}



inline void ScrollBar64::setValue( int64_t value )
{
    val = value < min ? min : value > max ? max : value;
    doIt();
    return;
}



inline QSize ScrollBar64::sizeHint() const
{
    return qscrollbar->sizeHint();
}



inline bool ScrollBar64::tracking() const
{
    return qscrollbar->tracking();
}



inline int64_t ScrollBar64::value() const
{
    return div * qscrollbar->value() - shift;
}



#endif
